Method: ConfigurationBlocks#configuration_block
- Defined in:
-
lib/configuration-blocks/core.rb,
lib/configuration-blocks/core.rb
Returns configuration module that delegates methods pointing to the given base object and optionally evaluates the given block in the context of this module or in the current context.
If a block is given then it is evaluated in the context of the configuration module. If a block with at least one argument is given then the context remains as it was but the first argument is the module.
25 26 27 |
# File 'lib/configuration-blocks/core.rb', line 25 def configuration_block(base = self, &block) self.class.configuration_block(base, &block) end |